@@ -2,7 +2,6 @@ from typing import List, Union
 from delphai_utils.users import get_user
 from grpc import StatusCode
 from grpc.aio import ServicerContext
-from delphai_utils.logging import logging
 import asyncio
 from functools import wraps
 
@@ -80,7 +79,6 @@ def authorize(required_roles: List[str], decission_logic: str = "all"):
                     return func(self, request, context, *args, **kwargs)
                 else:
                     details = f"Given roles don't intersect with {required_roles} using decission logic '{decission_logic}'"
-                    logging.warn(f"403 Forbidden: {details}")
                     context.abort(StatusCode.PERMISSION_DENIED, details)
 
             return wrapped_func
@@ -92,7 +90,6 @@ def authorize(required_roles: List[str], decission_logic: str = "all"):
                     return await func(self, request, context, *args, **kwargs)
                 else:
                     details = f"Given roles don't intersect with {required_roles} using decission logic '{decission_logic}'"
-                    logging.warn(f"403 Forbidden: {details}")
                     await context.abort(StatusCode.PERMISSION_DENIED, details)
 
             return wrapped_func
