@@ -1,4 +1,6 @@
-from typing import Union
+from itertools import chain
+import collections.abc
+from typing import Iterable, Iterator, Optional, Union, cast
 import asyncio
 import socket
 from grpc import Server, aio
@@ -6,7 +8,7 @@ from grpc_reflection.v1alpha import reflection
 from grpc_health.v1 import health, health_pb2_grpc
 from grpc_health.v1.health_pb2 import _HEALTH
 from delphai_utils.logging import logging
-from google.protobuf.descriptor import FileDescriptor
+from google.protobuf.descriptor import FileDescriptor, ServiceDescriptor
 from delphai_utils.gateway import start_gateway
 from delphai_utils.keycloak import update_public_keys
 from prometheus_client import start_http_server
@@ -64,42 +66,54 @@ def find_free_port(start: int, host="127.0.0.1", num_tries=4) -> int:
     raise NoPortFoundError(message)
 
 
-def create_grpc_server(descriptor: FileDescriptor):
-    max_length = 512 * 1024 * 1024
-    server_options = [
-        ("grpc.max_send_message_length", max_length),
-        ("grpc.max_receive_message_length", max_length),
-    ]
-    server = aio.server(
-        options=server_options,
+def create_grpc_server(
+    descriptors: Union[FileDescriptor, Iterable[FileDescriptor]],
+    server: Optional[aio.Server] = None,
+) -> aio.Server:
+    """Configures a grpc server based on one or multiple proto file descriptors.
+
+    A existing grpc server can be passed as configuration base. If not the
+    default configured grpc.aio.Server will be used.
+    """
+    if not isinstance(descriptors, collections.abc.Iterable):
+        descriptors = [descriptors]
+    max_message_length = 512 * 1024 * 1024
+    server = server or aio.server(
+        options=[
+            ("grpc.max_send_message_length", max_message_length),
+            ("grpc.max_receive_message_length", max_message_length),
+        ],
         interceptors=(
             AuthenticationInterceptor(),
             MetricsInterceptor(),
         ),
     )
-    server.__dict__["descriptor"] = descriptor
+
     health_servicer = health.HealthServicer(experimental_non_blocking=True)
     health_pb2_grpc.add_HealthServicer_to_server(health_servicer, server)
-    services = descriptor.services_by_name.keys()
-    service_full_names = list(
-        map(lambda service: descriptor.services_by_name[service].full_name, services)
+
+    services: Iterator[ServiceDescriptor] = chain.from_iterable(
+        [descriptor.services_by_name.values() for descriptor in descriptors]
     )
-    service_names = (
-        *service_full_names,
+    service_names = [service.full_name for service in services]
+    all_service_names = (
+        *service_names,
         _HEALTH.full_name,
         reflection.SERVICE_NAME,
     )
-    reflection.enable_server_reflection(service_names, server)
+    reflection.enable_server_reflection(all_service_names, server)
+    server.__dict__["descriptors"] = descriptors
     return server
 
 
 def start_server(
     server: Server,
     gateway: bool = True,
-    grpc_port: Union[int, None] = None,
-    http_port: Union[int, None] = None,
-    metrics_port: Union[int, None] = None,
+    grpc_port: Optional[int] = None,
+    http_port: Optional[int] = None,
+    metrics_port: Optional[int] = None,
 ):
+    """Start a grpc server including gateway and background tasks."""
     logging.info("starting grpc server...")
     if not grpc_port:
         grpc_port = find_free_port(8080)
@@ -113,10 +127,21 @@ def start_server(
     logging.info(f"started metrics server on port {metrics_port}")
     try:
         if gateway:
+            if "descriptors" not in server.__dict__:
+                raise RuntimeError(
+                    "Server instance does not include the proto file descriptors. Make sure you instantiate it with 'create_grpc_server'"
+                )
             if not http_port:
                 http_port = find_free_port(7070)
-            gateway = start_gateway(server.__dict__["descriptor"], grpc_port, http_port)
-            loop.create_task(gateway)
+            gateway_task = start_gateway(
+                cast(
+                    Union[FileDescriptor, Iterable[FileDescriptor]],
+                    server.__dict__["descriptors"],
+                ),
+                grpc_port,
+                http_port,
+            )
+            loop.create_task(gateway_task)
         loop.create_task(server.wait_for_termination())
         loop.create_task(update_public_keys())
         loop.run_forever()
