@@ -2,10 +2,11 @@ import re
 from functools import lru_cache
 from validate_email import validate_email
 import ipaddress
+
 try:
-  import urlparse
+    import urlparse
 except ImportError:
-  import urllib.parse as urlparse
+    import urllib.parse as urlparse
 import uuid
 import struct
 from jinja2 import Template
@@ -16,120 +17,127 @@ printer = ""
 
 # Well known regex mapping.
 regex_map = {
-  "UNKNOWN": "",
-  "HTTP_HEADER_NAME": r'^:?[0-9a-zA-Z!#$%&\'*+-.^_|~\x60]+$',
-  "HTTP_HEADER_VALUE": r'^[^\u0000-\u0008\u000A-\u001F\u007F]*$',
-  "HEADER_STRING": r'^[^\u0000\u000A\u000D]*$'
+    "UNKNOWN": "",
+    "HTTP_HEADER_NAME": r"^:?[0-9a-zA-Z!#$%&\'*+-.^_|~\x60]+$",
+    "HTTP_HEADER_VALUE": r"^[^\u0000-\u0008\u000A-\u001F\u007F]*$",
+    "HEADER_STRING": r"^[^\u0000\u000A\u000D]*$",
 }
 
 
 class ValidatingMessage(object):
-  """Wrap a proto message to cache validate functions with the message class name.
+    """Wrap a proto message to cache validate functions with the message class name.
 
     A validate function is defined per message class in protoc-gen-validate,
      so we can reuse an already generated function for the same message class.
     """
-  def __init__(self, proto_message):
-    self.DESCRIPTOR = proto_message.DESCRIPTOR
 
-  def __hash__(self):
-    return hash(self.DESCRIPTOR.full_name)
+    def __init__(self, proto_message):
+        self.DESCRIPTOR = proto_message.DESCRIPTOR
 
-  def __eq__(self, other):
-    if isinstance(other, ValidatingMessage):
-      return self.DESCRIPTOR.full_name == other.DESCRIPTOR.full_name
-    else:
-      return False
+    def __hash__(self):
+        return hash(self.DESCRIPTOR.full_name)
+
+    def __eq__(self, other):
+        if isinstance(other, ValidatingMessage):
+            return self.DESCRIPTOR.full_name == other.DESCRIPTOR.full_name
+        else:
+            return False
 
 
 def validate(proto_message):
-  return _validate_inner(ValidatingMessage(proto_message))
+    return _validate_inner(ValidatingMessage(proto_message))
 
 
 # Cache generated functions to avoid the performance issue caused by repeated proto messages,
 #   which generate the same functions repeatedly.
 @lru_cache()
 def _validate_inner(proto_message):
-  func = file_template(proto_message)
-  global printer
-  printer += func + "\n"
-  exec(func)
-  try:
-    return generate_validate
-  except NameError:
-    return locals()['generate_validate']
+    func = file_template(proto_message)
+    global printer
+    printer += func + "\n"
+    exec(func)
+    try:
+        return generate_validate
+    except NameError:
+        return locals()["generate_validate"]
 
 
 def print_validate(proto_message):
-  return "".join([s for s in printer.splitlines(True) if s.strip()])
+    return "".join([s for s in printer.splitlines(True) if s.strip()])
 
 
 def has_validate(field):
-  if field.GetOptions() is None:
+    if field.GetOptions() is None:
+        return False
+    for option_descriptor, option_value in field.GetOptions().ListFields():
+        if option_descriptor.full_name == "validate.rules":
+            return True
     return False
-  for option_descriptor, option_value in field.GetOptions().ListFields():
-    if option_descriptor.full_name == "validate.rules":
-      return True
-  return False
 
 
 def byte_len(s):
-  try:
-    return len(s.encode('utf-8'))
-  except:
-    return len(s)
+    try:
+        return len(s.encode("utf-8"))
+    except Exception:
+        return len(s)
 
 
 def _validateHostName(host):
-  if not host:
-    return False
-  if len(host) > 253:
-    return False
-
-  if host[-1] == '.':
-    host = host[:-1]
-
-  for part in host.split("."):
-    if len(part) == 0 or len(part) > 63:
-      return False
-
-    # Host names cannot begin or end with hyphens
-    if part[0] == "-" or part[-1] == '-':
-      return False
-    for r in part:
-      if (r < 'A' or r > 'Z') and (r < 'a' or r > 'z') and (r < '0' or r > '9') and r != '-':
+    if not host:
         return False
-  return True
+    if len(host) > 253:
+        return False
+
+    if host[-1] == ".":
+        host = host[:-1]
+
+    for part in host.split("."):
+        if len(part) == 0 or len(part) > 63:
+            return False
+
+        # Host names cannot begin or end with hyphens
+        if part[0] == "-" or part[-1] == "-":
+            return False
+        for r in part:
+            if (
+                (r < "A" or r > "Z")
+                and (r < "a" or r > "z")
+                and (r < "0" or r > "9")
+                and r != "-"
+            ):
+                return False
+    return True
 
 
 def _validateEmail(addr):
-  if '<' in addr and '>' in addr: addr = addr.split("<")[1].split(">")[0]
+    if "<" in addr and ">" in addr:
+        addr = addr.split("<")[1].split(">")[0]
 
-  if not validate_email(addr):
-    return False
+    if not validate_email(addr):
+        return False
 
-  if len(addr) > 254:
-    return False
+    if len(addr) > 254:
+        return False
 
-  parts = addr.split("@")
-  if len(parts[0]) > 64:
-    return False
-  return _validateHostName(parts[1])
+    parts = addr.split("@")
+    if len(parts[0]) > 64:
+        return False
+    return _validateHostName(parts[1])
 
 
 def _has_field(message_pb, property_name):
-  # NOTE: As of proto3, HasField() only works for message fields, not for
-  #       singular (non-message) fields. First try to use HasField and
-  #       if it fails (with a ValueError) we manually consult the fields.
-  try:
-    return message_pb.HasField(property_name)
-  except:
-    all_fields = set([field.name for field in message_pb.DESCRIPTOR.fields])
-    return property_name in all_fields
+    # NOTE: As of proto3, HasField() only works for message fields, not for
+    #       singular (non-message) fields. First try to use HasField and
+    #       if it fails (with a ValueError) we manually consult the fields.
+    try:
+        return message_pb.HasField(property_name)
+    except Exception:
+        all_fields = set([field.name for field in message_pb.DESCRIPTOR.fields])
+        return property_name in all_fields
 
 
 def const_template(option_value, name):
-  const_tmpl = """{%- if str(o.string) and o.string.HasField('const') -%}
+    const_tmpl = """{%- if str(o.string) and o.string.HasField('const') -%}
     if {{ name }} != \"{{ o.string['const'] }}\":
         raise ValidationFailed(\"{{ name }} not equal to {{ o.string['const'] }}\")
     {%- elif str(o.bool) and o.bool['const'] != "" -%}
@@ -148,11 +156,11 @@ def const_template(option_value, name):
         {% endif %}
     {%- endif -%}
     """
-  return Template(const_tmpl).render(sys=sys, o=option_value, name=name, str=str)
+    return Template(const_tmpl).render(sys=sys, o=option_value, name=name, str=str)
 
 
 def in_template(value, name):
-  in_tmpl = """
+    in_tmpl = """
     {%- if value['in'] %}
     if {{ name }} not in {{ value['in'] }}:
         raise ValidationFailed(\"{{ name }} not in {{ value['in'] }}\")
@@ -162,19 +170,24 @@ def in_template(value, name):
         raise ValidationFailed(\"{{ name }} in {{ value['not_in'] }}\")
     {%- endif -%}
     """
-  return Template(in_tmpl).render(value=value, name=name)
+    return Template(in_tmpl).render(value=value, name=name)
 
 
 def string_template(option_value, name):
-  if option_value.string.well_known_regex:
-    known_regex_type = option_value.string.DESCRIPTOR.fields_by_name['well_known_regex'].enum_type
-    regex_value = option_value.string.well_known_regex
-    regex_name = known_regex_type.values_by_number[regex_value].name
-    if regex_name in ["HTTP_HEADER_NAME", "HTTP_HEADER_VALUE"] and not option_value.string.strict:
-      option_value.string.pattern = regex_map["HEADER_STRING"]
-    else:
-      option_value.string.pattern = regex_map[regex_name]
-  str_templ = """
+    if option_value.string.well_known_regex:
+        known_regex_type = option_value.string.DESCRIPTOR.fields_by_name[
+            "well_known_regex"
+        ].enum_type
+        regex_value = option_value.string.well_known_regex
+        regex_name = known_regex_type.values_by_number[regex_value].name
+        if (
+            regex_name in ["HTTP_HEADER_NAME", "HTTP_HEADER_VALUE"]
+            and not option_value.string.strict
+        ):
+            option_value.string.pattern = regex_map["HEADER_STRING"]
+        else:
+            option_value.string.pattern = regex_map[regex_name]
+    str_templ = """
     {{ const_template(o, name) -}}
     {{ in_template(o.string, name) -}}
     {%- set s = o.string -%}
@@ -272,20 +285,25 @@ def string_template(option_value, name):
         raise ValidationFailed(\"{{ name }} is not a valid UUID\")
     {%- endif -%}
     """
-  return Template(str_templ).render(o=option_value, name=name, const_template=const_template, in_template=in_template)
+    return Template(str_templ).render(
+        o=option_value,
+        name=name,
+        const_template=const_template,
+        in_template=in_template,
+    )
 
 
 def required_template(value, name):
-  req_tmpl = """{%- if value['required'] -%}
+    req_tmpl = """{%- if value['required'] -%}
     if not _has_field(p, \"{{ name.split('.')[-1] }}\"):
         raise ValidationFailed(\"{{ name }} is required.\")
     {%- endif -%}
     """
-  return Template(req_tmpl).render(value=value, name=name)
+    return Template(req_tmpl).render(value=value, name=name)
 
 
 def message_template(option_value, name, repeated=False):
-  message_tmpl = """{%- if m.message %}
+    message_tmpl = """{%- if m.message %}
     {{- required_template(m.message, name) }}
     {%- endif -%}
     {%- if m.message and m.message['skip'] %}
@@ -301,21 +319,25 @@ def message_template(option_value, name, repeated=False):
             return embedded
     {%- endif -%}
     """
-  return Template(message_tmpl).render(m=option_value,
-                                       name=name,
-                                       required_template=required_template,
-                                       repeated=repeated)
+    return Template(message_tmpl).render(
+        m=option_value,
+        name=name,
+        required_template=required_template,
+        repeated=repeated,
+    )
 
 
 def bool_template(option_value, name):
-  bool_tmpl = """
+    bool_tmpl = """
     {{ const_template(o, name) -}}
     """
-  return Template(bool_tmpl).render(o=option_value, name=name, const_template=const_template)
+    return Template(bool_tmpl).render(
+        o=option_value, name=name, const_template=const_template
+    )
 
 
 def num_template(option_value, name, num):
-  num_tmpl = """{%- if num.HasField('const') and str(o.float) == "" -%}
+    num_tmpl = """{%- if num.HasField('const') and str(o.float) == "" -%}
     if {{ name }} != {{ num['const'] }}:
         raise ValidationFailed(\"{{ name }} not equal to {{ num['const'] }}\")
     {%- endif -%}
@@ -374,27 +396,29 @@ def num_template(option_value, name, num):
         raise ValidationFailed(\"{{ name }} is not greater than or equal to {{ num['gte'] }}\")
     {%- endif -%}
     """
-  return Template(num_tmpl).render(o=option_value, name=name, num=num, in_template=in_template, str=str)
+    return Template(num_tmpl).render(
+        o=option_value, name=name, num=num, in_template=in_template, str=str
+    )
 
 
 def dur_arr(dur):
-  value = 0
-  arr = []
-  for val in dur:
-    value += val.seconds
-    value += (10**-9 * val.nanos)
-    arr.append(value)
     value = 0
-  return arr
+    arr = []
+    for val in dur:
+        value += val.seconds
+        value += 10 ** -9 * val.nanos
+        arr.append(value)
+        value = 0
+    return arr
 
 
 def dur_lit(dur):
-  value = dur.seconds + (10**-9 * dur.nanos)
-  return value
+    value = dur.seconds + (10 ** -9 * dur.nanos)
+    return value
 
 
 def duration_template(option_value, name, repeated=False):
-  dur_tmpl = """
+    dur_tmpl = """
     {{- required_template(o.duration, name) }}
     {% if repeated %}
     if {{ name }}:
@@ -477,16 +501,18 @@ def duration_template(option_value, name, repeated=False):
             raise ValidationFailed(\"{{ name }} is not greater than or equal to {{ dur_lit(dur['gte']) }}\")
         {%- endif -%}
     """
-  return Template(dur_tmpl).render(o=option_value,
-                                   name=name,
-                                   required_template=required_template,
-                                   dur_lit=dur_lit,
-                                   dur_arr=dur_arr,
-                                   repeated=repeated)
+    return Template(dur_tmpl).render(
+        o=option_value,
+        name=name,
+        required_template=required_template,
+        dur_lit=dur_lit,
+        dur_arr=dur_arr,
+        repeated=repeated,
+    )
 
 
 def timestamp_template(option_value, name, repeated=False):
-  timestamp_tmpl = """
+    timestamp_tmpl = """
     {{- required_template(o.timestamp, name) }}
     {% if repeated %}
     if {{ name }}:
@@ -594,16 +620,18 @@ def timestamp_template(option_value, name, repeated=False):
              raise ValidationFailed(\"{{ name }} is not within range {{ dur_lit(ts['within']) }}\")
         {%- endif -%}
     """
-  return Template(timestamp_tmpl).render(o=option_value,
-                                         name=name,
-                                         required_template=required_template,
-                                         dur_lit=dur_lit,
-                                         dur_arr=dur_arr,
-                                         repeated=repeated)
+    return Template(timestamp_tmpl).render(
+        o=option_value,
+        name=name,
+        required_template=required_template,
+        dur_lit=dur_lit,
+        dur_arr=dur_arr,
+        repeated=repeated,
+    )
 
 
 def wrapper_template(option_value, name, repeated=False):
-  wrapper_tmpl = """
+    wrapper_tmpl = """
     {% if repeated %}
     if {{ name }}:
     {% else %}
@@ -641,22 +669,24 @@ def wrapper_template(option_value, name, repeated=False):
         raise ValidationFailed(\"{{ name }} is required.\")
     {%- endif %}
     """
-  return Template(wrapper_tmpl).render(option_value=option_value,
-                                       name=name,
-                                       str=str,
-                                       num_template=num_template,
-                                       bool_template=bool_template,
-                                       string_template=string_template,
-                                       bytes_template=bytes_template,
-                                       repeated=repeated)
+    return Template(wrapper_tmpl).render(
+        option_value=option_value,
+        name=name,
+        str=str,
+        num_template=num_template,
+        bool_template=bool_template,
+        string_template=string_template,
+        bytes_template=bytes_template,
+        repeated=repeated,
+    )
 
 
 def enum_values(field):
-  return [x.number for x in field.enum_type.values]
+    return [x.number for x in field.enum_type.values]
 
 
 def enum_template(option_value, name, field):
-  enum_tmpl = """
+    enum_tmpl = """
     {{ const_template(option_value, name) -}}
     {{ in_template(option_value.enum, name) -}}
     {% if option_value.enum['defined_only'] %}
@@ -664,16 +694,18 @@ def enum_template(option_value, name, field):
         raise ValidationFailed(\"{{ name }} is not defined\")
     {% endif %}
     """
-  return Template(enum_tmpl).render(option_value=option_value,
-                                    name=name,
-                                    const_template=const_template,
-                                    in_template=in_template,
-                                    field=field,
-                                    enum_values=enum_values)
+    return Template(enum_tmpl).render(
+        option_value=option_value,
+        name=name,
+        const_template=const_template,
+        in_template=in_template,
+        field=field,
+        enum_values=enum_values,
+    )
 
 
 def any_template(option_value, name, repeated=False):
-  any_tmpl = """
+    any_tmpl = """
     {{- required_template(o, name) }}
     {%- if o['in'] %}
     {% if repeated %}
@@ -694,14 +726,16 @@ def any_template(option_value, name, repeated=False):
             raise ValidationFailed(\"{{ name }} in {{ o['not_in'] }}\")
     {%- endif %}
     """
-  return Template(any_tmpl).render(o=option_value.any,
-                                   name=name,
-                                   required_template=required_template,
-                                   repeated=repeated)
+    return Template(any_tmpl).render(
+        o=option_value.any,
+        name=name,
+        required_template=required_template,
+        repeated=repeated,
+    )
 
 
 def bytes_template(option_value, name):
-  bytes_tmpl = """
+    bytes_tmpl = """
     {{ const_template(o, name) -}}
     {{ in_template(o.bytes, name) -}}
     {%- if b['len'] %}
@@ -771,16 +805,18 @@ def bytes_template(option_value, name):
         {% endif %}
     {% endif %}
     """
-  return Template(bytes_tmpl).render(sys=sys,
-                                     o=option_value,
-                                     name=name,
-                                     const_template=const_template,
-                                     in_template=in_template,
-                                     b=option_value.bytes)
+    return Template(bytes_tmpl).render(
+        sys=sys,
+        o=option_value,
+        name=name,
+        const_template=const_template,
+        in_template=in_template,
+        b=option_value.bytes,
+    )
 
 
 def switcher_template(accessor, name, field, map=False):
-  switcher_tmpl = """
+    switcher_tmpl = """
     {%- if str(accessor.float) %}
     {{- num_template(accessor, name, accessor.float)|indent(4,True) -}}
     {%- elif str(accessor.double) %}
@@ -825,23 +861,25 @@ def switcher_template(accessor, name, field, map=False):
     {{- message_template(accessor, name, True)|indent(4,True) -}}
     {%- endif %}
     """
-  return Template(switcher_tmpl).render(accessor=accessor,
-                                        name=name,
-                                        str=str,
-                                        num_template=num_template,
-                                        bool_template=bool_template,
-                                        string_template=string_template,
-                                        enum_template=enum_template,
-                                        duration_template=duration_template,
-                                        timestamp_template=timestamp_template,
-                                        any_template=any_template,
-                                        message_template=message_template,
-                                        field=field,
-                                        map=map)
+    return Template(switcher_tmpl).render(
+        accessor=accessor,
+        name=name,
+        str=str,
+        num_template=num_template,
+        bool_template=bool_template,
+        string_template=string_template,
+        enum_template=enum_template,
+        duration_template=duration_template,
+        timestamp_template=timestamp_template,
+        any_template=any_template,
+        message_template=message_template,
+        field=field,
+        map=map,
+    )
 
 
 def repeated_template(option_value, name, field):
-  rep_tmpl = """
+    rep_tmpl = """
     {%- if o and o.repeated['min_items'] %}
     if len({{ name }}) < {{ o.repeated['min_items'] }}:
         raise ValidationFailed(\"{{ name }} needs to contain at least {{ o.repeated['min_items'] }} items\")
@@ -873,21 +911,28 @@ def repeated_template(option_value, name, field):
         pass
     {%- endif %}
     """
-  return Template(rep_tmpl).render(o=option_value,
-                                   name=name,
-                                   message_type=field.message_type,
-                                   str=str,
-                                   field=field,
-                                   switcher_template=switcher_template)
+    return Template(rep_tmpl).render(
+        o=option_value,
+        name=name,
+        message_type=field.message_type,
+        str=str,
+        field=field,
+        switcher_template=switcher_template,
+    )
 
 
 def is_map(field):
-  return field.label == 3 and field.message_type and len(field.message_type.fields) == 2 and \
-         field.message_type.fields[0].name == "key" and field.message_type.fields[1].name == "value"
+    return (
+        field.label == 3
+        and field.message_type
+        and len(field.message_type.fields) == 2
+        and field.message_type.fields[0].name == "key"
+        and field.message_type.fields[1].name == "value"
+    )
 
 
 def map_template(option_value, name, field):
-  map_tmpl = """
+    map_tmpl = """
     {%- if o and o.map['min_pairs'] %}
     if len({{ name }}) < {{ o.map['min_pairs'] }}:
         raise ValidationFailed(\"{{ name }} needs to contain at least {{ o.map['min_pairs'] }} items\")
@@ -938,96 +983,106 @@ def map_template(option_value, name, field):
         validate({{ name }}[key])({{ name }}[key])
     {%- endif %}
     """
-  return Template(map_tmpl).render(o=option_value,
-                                   name=name,
-                                   message_type=field.message_type,
-                                   str=str,
-                                   field=field,
-                                   switcher_template=switcher_template,
-                                   num_template=num_template,
-                                   string_template=string_template,
-                                   bool_template=bool_template)
+    return Template(map_tmpl).render(
+        o=option_value,
+        name=name,
+        message_type=field.message_type,
+        str=str,
+        field=field,
+        switcher_template=switcher_template,
+        num_template=num_template,
+        string_template=string_template,
+        bool_template=bool_template,
+    )
 
 
 def rule_type(field):
-  name = "p." + field.name
-  if has_validate(field) and field.message_type is None:
-    for option_descriptor, option_value in field.GetOptions().ListFields():
-      if option_descriptor.full_name == "validate.rules":
-        if str(option_value.string):
-          return string_template(option_value, name)
-        elif str(option_value.message):
-          return message_template(option_value, field.name)
-        elif str(option_value.bool):
-          return bool_template(option_value, name)
-        elif str(option_value.float):
-          return num_template(option_value, name, option_value.float)
-        elif str(option_value.double):
-          return num_template(option_value, name, option_value.double)
-        elif str(option_value.int32):
-          return num_template(option_value, name, option_value.int32)
-        elif str(option_value.int64):
-          return num_template(option_value, name, option_value.int64)
-        elif str(option_value.uint32):
-          return num_template(option_value, name, option_value.uint32)
-        elif str(option_value.uint64):
-          return num_template(option_value, name, option_value.uint64)
-        elif str(option_value.sint32):
-          return num_template(option_value, name, option_value.sint32)
-        elif str(option_value.sint64):
-          return num_template(option_value, name, option_value.sint64)
-        elif str(option_value.fixed32):
-          return num_template(option_value, name, option_value.fixed32)
-        elif str(option_value.fixed64):
-          return num_template(option_value, name, option_value.fixed64)
-        elif str(option_value.sfixed32):
-          return num_template(option_value, name, option_value.sfixed32)
-        elif str(option_value.sfixed64):
-          return num_template(option_value, name, option_value.sfixed64)
-        elif str(option_value.enum):
-          return enum_template(option_value, name, field)
-        elif str(option_value.bytes):
-          return bytes_template(option_value, name)
-        elif str(option_value.repeated):
-          return repeated_template(option_value, name, field)
-        elif str(option_value.map):
-          return map_template(option_value, name, field)
-        elif str(option_value.required):
-          return required_template(option_value, name)
-  if field.message_type:
-    for option_descriptor, option_value in field.GetOptions().ListFields():
-      if option_descriptor.full_name == "validate.rules":
-        if str(option_value.duration):
-          return duration_template(option_value, name)
-        elif str(option_value.timestamp):
-          return timestamp_template(option_value, name)
-        elif str(option_value.float) or str(option_value.int32) or str(option_value.int64) or \
-                str(option_value.double) or str(option_value.uint32) or str(option_value.uint64) or \
-                str(option_value.bool) or str(option_value.string) or str(option_value.bytes):
-          return wrapper_template(option_value, name)
-        elif str(option_value.message) != "":
-          return message_template(option_value, field.name)
-        elif str(option_value.any):
-          return any_template(option_value, name)
-        elif str(option_value.repeated):
-          return repeated_template(option_value, name, field)
-        elif str(option_value.map):
-          return map_template(option_value, name, field)
-        elif str(option_value.required):
-          return required_template(option_value, name)
-    if field.message_type.full_name.startswith("google.protobuf"):
-      return ""
-    elif is_map(field):
-      return map_template(None, name, field)
-    elif field.label == 3:
-      return repeated_template(None, name, field)
-    else:
-      return message_template(None, field.name)
-  return ""
+    name = "p." + field.name
+    if has_validate(field) and field.message_type is None:
+        for option_descriptor, option_value in field.GetOptions().ListFields():
+            if option_descriptor.full_name == "validate.rules":
+                if str(option_value.string):
+                    return string_template(option_value, name)
+                elif str(option_value.message):
+                    return message_template(option_value, field.name)
+                elif str(option_value.bool):
+                    return bool_template(option_value, name)
+                elif str(option_value.float):
+                    return num_template(option_value, name, option_value.float)
+                elif str(option_value.double):
+                    return num_template(option_value, name, option_value.double)
+                elif str(option_value.int32):
+                    return num_template(option_value, name, option_value.int32)
+                elif str(option_value.int64):
+                    return num_template(option_value, name, option_value.int64)
+                elif str(option_value.uint32):
+                    return num_template(option_value, name, option_value.uint32)
+                elif str(option_value.uint64):
+                    return num_template(option_value, name, option_value.uint64)
+                elif str(option_value.sint32):
+                    return num_template(option_value, name, option_value.sint32)
+                elif str(option_value.sint64):
+                    return num_template(option_value, name, option_value.sint64)
+                elif str(option_value.fixed32):
+                    return num_template(option_value, name, option_value.fixed32)
+                elif str(option_value.fixed64):
+                    return num_template(option_value, name, option_value.fixed64)
+                elif str(option_value.sfixed32):
+                    return num_template(option_value, name, option_value.sfixed32)
+                elif str(option_value.sfixed64):
+                    return num_template(option_value, name, option_value.sfixed64)
+                elif str(option_value.enum):
+                    return enum_template(option_value, name, field)
+                elif str(option_value.bytes):
+                    return bytes_template(option_value, name)
+                elif str(option_value.repeated):
+                    return repeated_template(option_value, name, field)
+                elif str(option_value.map):
+                    return map_template(option_value, name, field)
+                elif str(option_value.required):
+                    return required_template(option_value, name)
+    if field.message_type:
+        for option_descriptor, option_value in field.GetOptions().ListFields():
+            if option_descriptor.full_name == "validate.rules":
+                if str(option_value.duration):
+                    return duration_template(option_value, name)
+                elif str(option_value.timestamp):
+                    return timestamp_template(option_value, name)
+                elif (
+                    str(option_value.float)
+                    or str(option_value.int32)
+                    or str(option_value.int64)
+                    or str(option_value.double)
+                    or str(option_value.uint32)
+                    or str(option_value.uint64)
+                    or str(option_value.bool)
+                    or str(option_value.string)
+                    or str(option_value.bytes)
+                ):
+                    return wrapper_template(option_value, name)
+                elif str(option_value.message) != "":
+                    return message_template(option_value, field.name)
+                elif str(option_value.any):
+                    return any_template(option_value, name)
+                elif str(option_value.repeated):
+                    return repeated_template(option_value, name, field)
+                elif str(option_value.map):
+                    return map_template(option_value, name, field)
+                elif str(option_value.required):
+                    return required_template(option_value, name)
+        if field.message_type.full_name.startswith("google.protobuf"):
+            return ""
+        elif is_map(field):
+            return map_template(None, name, field)
+        elif field.label == 3:
+            return repeated_template(None, name, field)
+        else:
+            return message_template(None, field.name)
+    return ""
 
 
 def file_template(proto_message):
-  file_tmp = """
+    file_tmp = """
 # Validates {{ p.DESCRIPTOR.name }}
 def generate_validate(p):
     {%- for option_descriptor, option_value in p.DESCRIPTOR.GetOptions().ListFields() %}
@@ -1055,12 +1110,12 @@ def generate_validate(p):
         {%- endif %}
     {%- endfor %}
     return None"""
-  return Template(file_tmp).render(rule_type=rule_type, p=proto_message)
+    return Template(file_tmp).render(rule_type=rule_type, p=proto_message)
 
 
 class UnimplementedException(Exception):
-  pass
+    pass
 
 
 class ValidationFailed(Exception):
-  pass
+    pass
